@@ -629,7 +629,7 @@ new_package <- function(license = "GPL (>= 2)", status = NULL,
   add_readme_rmd(type = "package", given, family, organisation, open = FALSE, 
                  overwrite = overwrite, quiet = quiet)
   
-  add_sticker(overwrite = overwrite, quiet = quiet)
+  add_sticker(type = "package", overwrite = overwrite, quiet = quiet)
   
   
   
@@ -706,7 +706,6 @@ new_package <- function(license = "GPL (>= 2)", status = NULL,
     ui_title("Configuring GH Actions - R CMD CHECK")
     
     add_github_actions_check(quiet = quiet)
-    add_to_buildignore(".github", quiet = quiet)
   }
   
   
@@ -722,7 +721,6 @@ new_package <- function(license = "GPL (>= 2)", status = NULL,
     ui_title("Configuring GH Actions - Code Coverage")
     
     add_github_actions_codecov(quiet = quiet)
-    add_to_buildignore(".github", quiet = quiet)
   }
   
   
@@ -738,7 +736,6 @@ new_package <- function(license = "GPL (>= 2)", status = NULL,
     ui_title("Configuring GH Actions - Render README")
     
     add_github_actions_render(quiet = quiet)
-    add_to_buildignore(".github", quiet = quiet)
   }
   
 
@@ -754,7 +751,6 @@ new_package <- function(license = "GPL (>= 2)", status = NULL,
     ui_title("Configuring GH Actions - Website deployment")
     
     add_github_actions_pkgdown()
-    add_to_buildignore(".github", quiet = quiet)
     
     ui_line()
     
@@ -774,7 +770,6 @@ new_package <- function(license = "GPL (>= 2)", status = NULL,
     ui_title("Configuring GH Actions - CITATION.cff")
     
     add_github_actions_citation(quiet = quiet)
-    add_to_buildignore(".github", quiet = quiet)
   }
 
   
